@@ -13,8 +13,8 @@ pub mod state;
 mod entrypoint;
 
 // Export current sdk types for downstream users building with a different sdk version
-pub use solana_program;
-use solana_program::{entrypoint::ProgramResult, program_error::ProgramError, pubkey::Pubkey};
+pub use safecoin_program;
+use safecoin_program::{entrypoint::ProgramResult, program_error::ProgramError, pubkey::Pubkey};
 
 /// Convert the UI representation of a token amount (using the decimals field defined in its mint)
 /// to the raw amount
@@ -27,11 +27,11 @@ pub fn amount_to_ui_amount(amount: u64, decimals: u8) -> f64 {
     amount as f64 / 10_usize.pow(decimals as u32) as f64
 }
 
-solana_program::declare_id!("7v5TwK92hUSqduoL3R8NtzTNfNzMA48nJL4mzPYMdDrD");
+safecoin_program::declare_id!("ToKLx75MGim1d1jRusuVX8xvdvvbSDESVaNXpRA9PHN");
 
 /// Checks that the supplied program ID is the correct one for SPL-token
-pub fn check_program_account(spl_token_id_program_id: &Pubkey) -> ProgramResult {
-    if spl_token_id_program_id != &id() {
+pub fn check_program_account(safe_token_program_id: &Pubkey) -> ProgramResult {
+    if safe_token_program_id != &id() {
         return Err(ProgramError::IncorrectProgramId);
     }
     Ok(())
